==> highcharts-angular-2.9.0.tgz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

## [2.9.0](https://github.com/highcharts/highcharts-angular/compare/v2.8.1...v2.9.0) (2021-01-04)

### Features

* Added common TS error example to the online examples, and the FAQ section. ([6c13fdd](https://github.com/highcharts/highcharts-angular/commit/6c13fdd21ac524140046f3a81fcedf24b2fae608))
* Added how to use proj4 to the online examples, and the FAQ section. ([7f02d4e](https://github.com/highcharts/highcharts-angular/commit/7f02d4e887cc8d36b6adbac5f5e9bef3d8991358))
* Added portals demo to the online examples, and the FAQ section. ([5e166bf](https://github.com/highcharts/highcharts-angular/commit/5e166bfba22ed9038b0bbd564ec7524025ae2cec))
* Updated Highcharts products names in the README file. ([4831134](https://github.com/highcharts/highcharts-angular/commit/4831134e2e0a7f1a6295e0cb891850f38703157d))
* Updated Angular to version 10. ([df1a505](https://github.com/highcharts/highcharts-angular/pull/257/commits/4cff05426831f8f524535c4d285b1b117495961a))


### [2.8.2](https://github.com/highcharts/highcharts-angular/compare/v2.8.1...v2.8.2) (2020-11-02)

### Bug Fixes

* Changed peer dependencies. ([07e6209](https://github.com/highcharts/highcharts-angular/pull/228/commits/07e6209e594e6026faae394a7b9b3edd5fdcc4b5))

# [2.8.0](https://github.com/highcharts/highcharts-angular/compare/v2.4.0...v2.8.0) (2020-08-31)

### Features

* Updated Angular to version 10. ([a28190c](https://github.com/highcharts/highcharts-angular/pull/219/commits/a28190cd6a14be4d74c57868eaaba49c137700c7))
* Added Tests for creating a simple component.  ([d6107dd](https://github.com/highcharts/highcharts-angular/pull/219/commits/d6107dd4b75d87add8c7213356bf2f383bd79b85))
* Added a paragraph about SSR in the README.  ([9269c55](https://github.com/highcharts/highcharts-angular/pull/219/commits/9269c55f993b234284a01e11eaa439c9cf206050))


### Bug Fixes

* Fixed lazy-loading demo. ([de88e2a](https://github.com/highcharts/highcharts-angular/pull/219/commits/de88e2a54b9060b87ee458048943b8dfb2db5956))

# [2.7.0](https://github.com/highcharts/highcharts-angular/compare/v2.4.0...v2.7.0) (2020-07-24)

### Features

* Add issue templates. Closes [#100](https://github.com/highcharts/highcharts-angular/issues/100). ([1fcbb42](https://github.com/highcharts/highcharts-angular/commit/1fcbb428772897df0fc978c1a40aa69a0687d704))
* Added online examples in the README. ([fe78157](https://github.com/highcharts/highcharts-angular/commit/fe7815770dc2eab7191e2d1cea589b93b17fd2e7))
* Disabled ivy in tsconfig ([0f97065](https://github.com/highcharts/highcharts-angular/commit/0f970651cb6e5f53737b13d950a5ffcc4600a353))
* Extracted charts to separate components for the demo project. ([e8d401b](https://github.com/highcharts/highcharts-angular/commit/e8d401b9b785116ac551a21373aa5fddd994fdcf))
* Updated Angular to version 9. ([5832ff1](https://github.com/highcharts/highcharts-angular/commit/5832ff1532f54f87a7fa2f81282de67583909d38))
* Updated Highcharts version. ([dd9740f](https://github.com/highcharts/highcharts-angular/commit/dd9740f4b5e8677f89765dfa0ff179aeb6e5adb4))
* Updated the README. ([f54ec96](https://github.com/highcharts/highcharts-angular/commit/f54ec960473aabf27936d3b282e16ba3e01aeec7))
* Updated styles of the demo project. ([d56354a](https://github.com/highcharts/highcharts-angular/commit/d56354ab9c9134364b95a245e7393a15123c42b2))


### Bug Fixes

* Disabled aot and related dependency. ([19ff85d](https://github.com/highcharts/highcharts-angular/commit/19ff85d54ff3016caea66c390445f0c10ade2cfe))

__
## 2.5.0 - 2.6.0 (2020-07-23)

Due to problems with publishing the package, redundant versions have been released. Please do not use these versions.

__
<a name="2.4.0"></a>
# [2.4.0](https://github.com/highcharts/highcharts-angular/compare/v2.1.3...v2.4.0) (2018-12-27)


### Features

* Added chart instance as the component's output. Closes [#26](https://github.com/highcharts/highcharts-angular/issues/26). ([04c2bd8](https://github.com/highcharts/highcharts-angular/commit/04c2bd8))
* Added demo for FAQ's about Synchronized charts. Closes [#93](https://github.com/highcharts/highcharts-angular/issues/93). ([1362608](https://github.com/highcharts/highcharts-angular/commit/1362608))
* Added reference to [@highcharts](https://github.com/highcharts)/map-collection and updated documentation. Closes [#89](https://github.com/highcharts/highcharts-angular/issues/89), closes [#104](https://github.com/highcharts/highcharts-angular/issues/104). ([c5081f0](https://github.com/highcharts/highcharts-angular/commit/c5081f0))
* Added support for optional running Highcharts outside of Angular. Closes [#75](https://github.com/highcharts/highcharts-angular/issues/75). ([2ebcb07](https://github.com/highcharts/highcharts-angular/commit/2ebcb07))
* Added TS definitions from Highcharts into the wrapper for types reference. ([56d93fa](https://github.com/highcharts/highcharts-angular/commit/56d93fa))
* Closes [#84](https://github.com/highcharts/highcharts-angular/issues/84), added info about Highcharts instance being shared in an Angular app. ([7aa3b32](https://github.com/highcharts/highcharts-angular/commit/7aa3b32))
* Refreshed and updated demo with some CSS and TS definitions. ([acc13b2](https://github.com/highcharts/highcharts-angular/commit/acc13b2))
* Update tslint rules. See PR [#98](https://github.com/highcharts/highcharts-angular/issues/98). ([4dc85da](https://github.com/highcharts/highcharts-angular/commit/4dc85da))
* Updated demo to version 7 for Highcharts and Angular. ([85151bf](https://github.com/highcharts/highcharts-angular/commit/85151bf))



<a name="2.3.1"></a>
## [2.3.1](https://github.com/highcharts/highcharts-angular/compare/v2.3.0...v2.3.1) (2018-10-05)


<a name="2.3.0"></a>
# [2.3.0](https://github.com/highcharts/highcharts-angular/compare/v2.2.0...v2.3.0) (2018-10-04)


### Features

* Added chart instance as the component's output. Closes [#26](https://github.com/highcharts/highcharts-angular/issues/26). ([04c2bd8](https://github.com/highcharts/highcharts-angular/commit/04c2bd8))



<a name="2.2.0"></a>
# [2.2.0](https://github.com/highcharts/highcharts-angular/compare/v2.1.3...v2.2.0) (2018-09-28)


### Features

* Added support for optional running Highcharts outside of Angular. Closes [#75](https://github.com/highcharts/highcharts-angular/issues/75). ([2ebcb07](https://github.com/highcharts/highcharts-angular/commit/2ebcb07))



<a name="2.1.3"></a>
## [2.1.3](https://github.com/highcharts/highcharts-angular/compare/v2.1.2...v2.1.3) (2018-08-27)



<a name="2.1.2"></a>
## [2.1.2](https://github.com/highcharts/highcharts-angular/compare/v2.1.1...v2.1.2) (2018-08-24)



<a name="2.1.1"></a>
## [2.1.1](https://github.com/highcharts/highcharts-angular/compare/v2.1.0...v2.1.1) (2018-08-24)



<a name="2.1.0"></a>
# [2.1.0](https://github.com/highcharts/highcharts-angular/compare/v2.0.3...v2.1.0) (2018-08-24)


### Features

* Added CHANGELOG.md and updated related documentation. ([8452557](https://github.com/highcharts/highcharts-angular/commit/8452557))

==> highcharts-angular-2.10.0.tgz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

## [2.9.1](https://github.com/highcharts/highcharts-angular/compare/v2.8.1...v2.10.0) (2021-02-09)

### Features

* Updated Highcharts to 9.0.0 version. ([e23e896](https://github.com/highcharts/highcharts-angular/pull/267/commits/e23e896b8ff0ac49f8756b5e343ad4c39305c216))

### Bug Fixes

* fixed incorrect link ([c274d5e](https://github.com/highcharts/highcharts-angular/commit/c274d5edc5457f09f1e0631ea29c0f88a0145726))

# [2.9.0](https://github.com/highcharts/highcharts-angular/compare/v2.8.1...v2.9.0) (2021-01-04)

### Features

* Added common TS error example to the online examples, and the FAQ section. ([6c13fdd](https://github.com/highcharts/highcharts-angular/commit/6c13fdd21ac524140046f3a81fcedf24b2fae608))
* Added how to use proj4 to the online examples, and the FAQ section. ([7f02d4e](https://github.com/highcharts/highcharts-angular/commit/7f02d4e887cc8d36b6adbac5f5e9bef3d8991358))
* Added portals demo to the online examples, and the FAQ section. ([5e166bf](https://github.com/highcharts/highcharts-angular/commit/5e166bfba22ed9038b0bbd564ec7524025ae2cec))
* Updated Highcharts products names in the README file. ([4831134](https://github.com/highcharts/highcharts-angular/commit/4831134e2e0a7f1a6295e0cb891850f38703157d))
* Updated Angular to version 11. ([594c411](https://github.com/highcharts/highcharts-angular/pull/257/commits/594c4112eb30b093649fe8ee0a36abc0642c589b))

## [2.8.2](https://github.com/highcharts/highcharts-angular/compare/v2.8.1...v2.8.2) (2020-11-02)

### Bug Fixes

* Changed peer dependencies. ([07e6209](https://github.com/highcharts/highcharts-angular/pull/228/commits/07e6209e594e6026faae394a7b9b3edd5fdcc4b5))

# [2.8.0](https://github.com/highcharts/highcharts-angular/compare/v2.4.0...v2.8.0) (2020-08-31)

### Features

* Updated Angular to version 10. ([a28190c](https://github.com/highcharts/highcharts-angular/pull/219/commits/a28190cd6a14be4d74c57868eaaba49c137700c7))
* Added Tests for creating a simple component.  ([d6107dd](https://github.com/highcharts/highcharts-angular/pull/219/commits/d6107dd4b75d87add8c7213356bf2f383bd79b85))
* Added a paragraph about SSR in the README.  ([9269c55](https://github.com/highcharts/highcharts-angular/pull/219/commits/9269c55f993b234284a01e11eaa439c9cf206050))


### Bug Fixes

* Fixed lazy-loading demo. ([de88e2a](https://github.com/highcharts/highcharts-angular/pull/219/commits/de88e2a54b9060b87ee458048943b8dfb2db5956))

# [2.7.0](https://github.com/highcharts/highcharts-angular/compare/v2.4.0...v2.7.0) (2020-07-24)

### Features

* Add issue templates. Closes [#100](https://github.com/highcharts/highcharts-angular/issues/100). ([1fcbb42](https://github.com/highcharts/highcharts-angular/commit/1fcbb428772897df0fc978c1a40aa69a0687d704))
* Added online examples in the README. ([fe78157](https://github.com/highcharts/highcharts-angular/commit/fe7815770dc2eab7191e2d1cea589b93b17fd2e7))
* Disabled ivy in tsconfig ([0f97065](https://github.com/highcharts/highcharts-angular/commit/0f970651cb6e5f53737b13d950a5ffcc4600a353))
* Extracted charts to separate components for the demo project. ([e8d401b](https://github.com/highcharts/highcharts-angular/commit/e8d401b9b785116ac551a21373aa5fddd994fdcf))
* Updated Angular to version 9. ([5832ff1](https://github.com/highcharts/highcharts-angular/commit/5832ff1532f54f87a7fa2f81282de67583909d38))
* Updated Highcharts version. ([dd9740f](https://github.com/highcharts/highcharts-angular/commit/dd9740f4b5e8677f89765dfa0ff179aeb6e5adb4))
* Updated the README. ([f54ec96](https://github.com/highcharts/highcharts-angular/commit/f54ec960473aabf27936d3b282e16ba3e01aeec7))
* Updated styles of the demo project. ([d56354a](https://github.com/highcharts/highcharts-angular/commit/d56354ab9c9134364b95a245e7393a15123c42b2))


### Bug Fixes

* Disabled aot and related dependency. ([19ff85d](https://github.com/highcharts/highcharts-angular/commit/19ff85d54ff3016caea66c390445f0c10ade2cfe))

__
## 2.5.0 - 2.6.0 (2020-07-23)

Due to problems with publishing the package, redundant versions have been released. Please do not use these versions.

__
<a name="2.4.0"></a>
# [2.4.0](https://github.com/highcharts/highcharts-angular/compare/v2.1.3...v2.4.0) (2018-12-27)


### Features

* Added chart instance as the component's output. Closes [#26](https://github.com/highcharts/highcharts-angular/issues/26). ([04c2bd8](https://github.com/highcharts/highcharts-angular/commit/04c2bd8))
* Added demo for FAQ's about Synchronized charts. Closes [#93](https://github.com/highcharts/highcharts-angular/issues/93). ([1362608](https://github.com/highcharts/highcharts-angular/commit/1362608))
* Added reference to [@highcharts](https://github.com/highcharts)/map-collection and updated documentation. Closes [#89](https://github.com/highcharts/highcharts-angular/issues/89), closes [#104](https://github.com/highcharts/highcharts-angular/issues/104). ([c5081f0](https://github.com/highcharts/highcharts-angular/commit/c5081f0))
* Added support for optional running Highcharts outside of Angular. Closes [#75](https://github.com/highcharts/highcharts-angular/issues/75). ([2ebcb07](https://github.com/highcharts/highcharts-angular/commit/2ebcb07))
* Added TS definitions from Highcharts into the wrapper for types reference. ([56d93fa](https://github.com/highcharts/highcharts-angular/commit/56d93fa))
* Closes [#84](https://github.com/highcharts/highcharts-angular/issues/84), added info about Highcharts instance being shared in an Angular app. ([7aa3b32](https://github.com/highcharts/highcharts-angular/commit/7aa3b32))
* Refreshed and updated demo with some CSS and TS definitions. ([acc13b2](https://github.com/highcharts/highcharts-angular/commit/acc13b2))
* Update tslint rules. See PR [#98](https://github.com/highcharts/highcharts-angular/issues/98). ([4dc85da](https://github.com/highcharts/highcharts-angular/commit/4dc85da))
* Updated demo to version 7 for Highcharts and Angular. ([85151bf](https://github.com/highcharts/highcharts-angular/commit/85151bf))



<a name="2.3.1"></a>
## [2.3.1](https://github.com/highcharts/highcharts-angular/compare/v2.3.0...v2.3.1) (2018-10-05)


<a name="2.3.0"></a>
# [2.3.0](https://github.com/highcharts/highcharts-angular/compare/v2.2.0...v2.3.0) (2018-10-04)


### Features

* Added chart instance as the component's output. Closes [#26](https://github.com/highcharts/highcharts-angular/issues/26). ([04c2bd8](https://github.com/highcharts/highcharts-angular/commit/04c2bd8))



<a name="2.2.0"></a>
# [2.2.0](https://github.com/highcharts/highcharts-angular/compare/v2.1.3...v2.2.0) (2018-09-28)


### Features

* Added support for optional running Highcharts outside of Angular. Closes [#75](https://github.com/highcharts/highcharts-angular/issues/75). ([2ebcb07](https://github.com/highcharts/highcharts-angular/commit/2ebcb07))



<a name="2.1.3"></a>
## [2.1.3](https://github.com/highcharts/highcharts-angular/compare/v2.1.2...v2.1.3) (2018-08-27)



<a name="2.1.2"></a>
## [2.1.2](https://github.com/highcharts/highcharts-angular/compare/v2.1.1...v2.1.2) (2018-08-24)



<a name="2.1.1"></a>
## [2.1.1](https://github.com/highcharts/highcharts-angular/compare/v2.1.0...v2.1.1) (2018-08-24)



<a name="2.1.0"></a>
# [2.1.0](https://github.com/highcharts/highcharts-angular/compare/v2.0.3...v2.1.0) (2018-08-24)


### Features

* Added CHANGELOG.md and updated related documentation. ([8452557](https://github.com/highcharts/highcharts-angular/commit/8452557))
